@@ -172,6 +172,17 @@ def set_tplot_options(option, value, old_tplot_opt_glob):
     return new_tplot_opt_glob
 
 
+def str_to_float_fuzzy(time_str):
+    """
+    Implementation of str_to_int (below) that uses dateutil and .timestamp()
+    to convert the date/time string to integer (number of seconds since Jan 1, 1970)
+
+    This function is slower than str_to_int, but more flexible
+    """
+    dt_object = parse(time_str)
+    return dt_object.replace(tzinfo=datetime.timezone.utc).timestamp()
+
+
 def str_to_int_fuzzy(time_str):
     """
     Implementation of str_to_int (below) that uses dateutil and .timestamp()
